@@ -4,7 +4,7 @@ use 5.008008;
 use strict;
 use warnings;
 
-our $VERSION = '2.3';
+our $VERSION = '2.31';
 
 use Text::Sentence qw( split_sentences );
 use Lingua::NegEx qw( negation_scope );
@@ -16,7 +16,8 @@ use Class::MakeMethods (
 		'absolute_present_phrases', 'absolute_negative_phrases',
   ],
   'Template::Hash:scalar' => [
-        'orig_text', 'final_answer', 'ambiguous', 'start_phrase',
+        'orig_text', 'final_answer', 'ambiguous', 
+		'start_phrase',
   ],
   'Template::Hash:hash' => [
         'target_sentence', 'negex_debug',
@@ -30,7 +31,7 @@ sub new {
   my $package = ref $callee || $callee;
   my $self = shift;
   bless $self, $package;
-  die unless $self->target_phrases;
+  die 'Need to define target phrases' unless $self->target_phrases;
   return $self;
 }
 
@@ -106,17 +107,17 @@ sub examine_text {
     $self->final_answer( 'absent' );
   }
   
+
+  if ( grep { $text =~ /$_/i } @{$self->absolute_negative_phrases} and $self->final_answer eq 'present' ) {
+    $self->final_answer( 'absent' );
+	$self->ambiguous( 3 ); 
+  }
   if ( grep { $text =~ /$_/i } @{$self->absolute_present_phrases} and $self->final_answer eq 'absent' ) {
     $self->final_answer( 'present' );
 	$self->ambiguous( 2 );
   }
-  if ( grep { $text =~ /$_/i } @{$self->absolute_negative_phrases} and $self->final_answer eq 'present' ) {
-    $self->final_answer( 'absent' );
-	$self->ambiguous( 3 ); 
-  } 
 }
 
-
 sub debug {
   my $self = shift;
   my $out = "Target Phrases(" . (join ', ', map { qq{'$_'} } @{$self->target_phrases}) . ")\r\n\r\n";
@@ -149,7 +150,7 @@ sub reset {
 
 =head1 NAME
 
-Lingua::DxExtractor - Perl extension to extract the presence or absence of a clinical condition from radiology reports. 
+Lingua::DxExtractor - Perl extension to extract the presence or absence of a clinical condition from medical reports. 
 
 =head1 SYNOPSIS
 
@@ -179,11 +180,11 @@ Lingua::DxExtractor - Perl extension to extract the presence or absence of a cli
 
 =head1 DESCRIPTION
 
-A tool to be used to look for the presence or absence of a clinical condition as reported in radiology reports. The extractor reports a 'final answer', 'absent' or 'present', as well as reports whether this answer is 'ambiguous' or not.
+A tool to be used to look for the presence or absence of a clinical condition as reported in medical reports. The extractor reports a 'final answer', 'absent' or 'present', as well as reports whether this answer is 'ambiguous' or not.
 
-The 'use case' for this is when performing a research project with a large number of records and you need to identify a subset based on a diagnostic entity, you can use this tool to reduce the number of charts that have to be manually examined. In this 'use case' I wanted to keep the sensitivity as high as possible in order to not miss real cases.
+The 'use case' for this is when performing a research project with a large number of records and you need to identify a subset based on a diagnostic entity, you can use this tool to reduce the number of charts that have to be manually examined.
 
-The radiographic reports don't require textual preprocessing however clearly the selection of target_phrases and skip_phrases requires reading through reports to get a sense of what vocabulary is being used in the particular dataset that is being evaluated.
+The medical reports don't require textual preprocessing however clearly the selection of target_phrases and skip_phrases requires reading through reports to get a sense of what vocabulary is being used in the particular dataset that is being evaluated.
 
 Negated terms are identified using Lingua::NegEx which is a perl implementation of Wendy Chapman's NegEx algorithm.
 
@@ -209,27 +210,29 @@ This is a list of phrases which if present in the text mean the condition is cer
 
   start_phrase( $start_phrase );
 
-A phrase if present in the text which indicates where to focus the search.
+A phrase if present in the text which indicates where to focus the search. All text prior to the start_phrase is ignored. Often times in radiology reports there is a 'Conclusion: ' or 'Impression: ' section which can be reviewed rather than analyzing the full report.
 
-=head2 Analysis
+=head2 ANALYSIS
 
 Once defined, the extractor object you created can be used to analyze target text. The analysis consists of:
 
 1. If there is a start phrase defined, eliminate all text for analysis prior to the start phrase.
 
-2. Change all colons ':' into periods '.' to treat them as sentence breaks
+2. Make text all lowercase, eliminate extra spaces, and change all colons ':' into periods '.' to treat them as sentence breaks.
 
-3. Split text into sentences using Text::Sentence
+3. Split text into sentences using Text::Sentence.
 
 4. Examine each sentence for the presence of any skip phrases and if found, ignore the sentence.
 
 5. Examine each sentence for the presence of any target phrases and if found evaluate for negation using Lingua:Negex.
-  if no negation found, mark this sentence as 'present'
-  if the target phrase is negated then mark the sentence as 'absent'
+
+-if no negation found, mark this sentence as 'present'
+
+-if the target phrase is negated then mark the sentence as 'absent'
 
 6. Go through all the flagged sentences and see if there is any discrepancy -- if so set the ambiguous flag. If there are more sentences that indicate absent than those that indicate present then mark the final answer as absent and vice versa. If there are an equal number of absent and present phrases mark the final answer as present.
 
-7. The possible values for ambiguous: 1 = there were some positive and some absent sentences; 2 = there was a match on an absolute positive phrase but the answer was going to be absent had this absolute phrase not been indicated; 3 = there was a match on an absolute negative phrase but the answer was going to be present had this absolute phrase not been indicated;
+7. The possible values for ambiguous: 1 = there were some positive and some absent sentences; 2 = there was a match on an absolute positive phrase but the answer was going to be absent had this absolute phrase not been indicated; 3 = there was a match on an absolute negative phrase but the answer was going to be present had this absolute phrase not been indicated; If both an absolute positive and negation phrase was present, mark the final answer as present.
 
 =head2 EXPORT
 
@@ -239,12 +242,12 @@ None by default.
 
 This module depends on:
 
-Lingua::NegEx
-
 Text::Sentence
 
 Class::MakeMethods
 
+Lingua::NegEx
+
 =head1 To Do
 
 Add lemmatization or stemming to target_phrases so you don't have to explicitly write out all forms of words 
